@@ -2,7 +2,13 @@ import doctest
 from textops import *
 import os
 
-modules = [ 'textops.ops.strops', 'textops.ops.listops', 'textops.ops.cast']
+modules = [ 'textops.base',
+            'textops.ops.strops',
+            'textops.ops.listops',
+            'textops.ops.wrapops',
+            'textops.ops.cast',
+            'textops.ops.parse',
+            ]
 files = [ 'docs/intro.rst' ]
 
 failed = 0
